
# Create your models here.
from django.db import models
from ResizedImageField import ResizedImageField

class Portfolio(models.Model):
    name = models.CharField(max_length=100)
    slug = models.SlugField(max_length=50,unique=True, db_index=True,
        help_text='Unique value for portfolio url, created from name.')
    description = models.TextField()
    order = models.IntegerField(unique=True, db_index=True)
    photo = ResizedImageField(upload_to="folios",
        help_text="Expecting a 200x200 pixel image",
        max_width=288,max_height=288)
    is_active = models.BooleanField(default=True, db_index=True)
    meta_keywords = models.CharField("Meta Keywords",max_length=255)
    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)

    def __unicode__(self):
        return self.name

class Work(models.Model):
    name = models.CharField(max_length=100)
    portfolio = models.ForeignKey(Portfolio, on_delete=models.CASCADE,
    related_name='works')
    description = models.TextField()
    is_active = models.BooleanField(default=True, db_index=True)
    photo = models.ImageField(upload_to="works")
    thumbnail = ResizedImageField(upload_to="works/thumbnails", max_width=288, max_height=288,
        help_text="Expecting 288x288 pixel image (will downsize if required)")
    meta_keywords = models.CharField("Meta Keywords", max_length=255)
    created_at = models.DateTimeField(auto_now_add=True)

    def __unicode__(self):
        return self.name

    
